==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebGroupByRowSelectorTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRowSelectorTemplateDetailsDescriptionMetadata } from "./WebGroupByRowSelectorTemplateDetailsDescriptionMetadata";
import { WebGroupByRowSelectorTemplateContextDescription } from "./WebGroupByRowSelectorTemplateContextDescription";
/**
 * @hidden
 */
var WebGroupByRowSelectorTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupByRowSelectorTemplateContextDescriptionMetadata, _super);
    function WebGroupByRowSelectorTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGroupByRowSelectorTemplateContextDescriptionMetadata.a == null) {
            WebGroupByRowSelectorTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByRowSelectorTemplateContextDescriptionMetadata.c(WebGroupByRowSelectorTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGroupByRowSelectorTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebGroupByRowSelectorTemplateContextDescriptionMetadata.a);
        WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.d(a);
    };
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByRowSelectorTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "ExportedType:WebGroupByRowSelectorTemplateDetails");
    };
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.d = function (a) {
        WebGroupByRowSelectorTemplateContextDescriptionMetadata.b(a);
        a.ad("WebGroupByRowSelectorTemplateContext", function () { return new WebGroupByRowSelectorTemplateContextDescription(); });
        a.ac("WebGroupByRowSelectorTemplateContext", WebGroupByRowSelectorTemplateContextDescriptionMetadata.a);
    };
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.$t = markType(WebGroupByRowSelectorTemplateContextDescriptionMetadata, 'WebGroupByRowSelectorTemplateContextDescriptionMetadata');
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.a = null;
    return WebGroupByRowSelectorTemplateContextDescriptionMetadata;
}(Base));
export { WebGroupByRowSelectorTemplateContextDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebGroupByRowSelectorTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRowSelectorTemplateDetailsDescriptionMetadata } from "./WebGroupByRowSelectorTemplateDetailsDescriptionMetadata";
import { WebGroupByRowSelectorTemplateContextDescription } from "./WebGroupByRowSelectorTemplateContextDescription";
/**
 * @hidden
 */
var WebGroupByRowSelectorTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupByRowSelectorTemplateContextDescriptionMetadata, _super);
    function WebGroupByRowSelectorTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGroupByRowSelectorTemplateContextDescriptionMetadata.a == null) {
            WebGroupByRowSelectorTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByRowSelectorTemplateContextDescriptionMetadata.c(WebGroupByRowSelectorTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGroupByRowSelectorTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebGroupByRowSelectorTemplateContextDescriptionMetadata.a);
        WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.d(a);
    };
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByRowSelectorTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "ExportedType:WebGroupByRowSelectorTemplateDetails");
    };
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.d = function (a) {
        WebGroupByRowSelectorTemplateContextDescriptionMetadata.b(a);
        a.ae("WebGroupByRowSelectorTemplateContext", function () { return new WebGroupByRowSelectorTemplateContextDescription(); });
        a.ad("WebGroupByRowSelectorTemplateContext", WebGroupByRowSelectorTemplateContextDescriptionMetadata.a);
    };
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.$t = markType(WebGroupByRowSelectorTemplateContextDescriptionMetadata, 'WebGroupByRowSelectorTemplateContextDescriptionMetadata');
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.a = null;
    return WebGroupByRowSelectorTemplateContextDescriptionMetadata;
}(Base));
export { WebGroupByRowSelectorTemplateContextDescriptionMetadata };
